/* Source Installer, Copyright (c) 2006 Claudio Fontana

 mf_features.h - makefile features

 This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.

 This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
     along with this program (look for the file called COPYING);
     if not, write to the Free Software Foundation, Inc.,
         51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

     You can contact the author (Claudio Fontana) by sending a mail
     to claudio@gnu.org
*/

#ifndef SRCINST_MF_FEATURES_H
#define SRCINST_MF_FEATURES_H

struct _makefile_feature {
  char* pattern;
  int supported;
};

struct _makefile_features {
  char* makefile;
  struct _makefile_feature features[SRCINST_FEATURE_N];
};

struct _makefile_features* _detect_makefile_features(void);
void _free_makefile_features(struct _makefile_features* mf);

#endif
